function [nominalCFreqs, exactCFreqs, fLow, fHigh] = DA_GenOctBandFreqs(OctOrThird, fmin, fmax, base)
% octave band frequencies
% according to ANSI S1.11-2004: Specification for Octave, Half-Octave, and Third Octave Band Filter Sets
% are returned between fmin and fmax
%
% nominal center frequencies: the nicely formatted center frequencies
% exact center frequencies: the base-ten exact center frequencies with
% fLow: the exact lower limit frequencies of the bands
% fHigh: the exact lower limit frequencies of the bands
%
% octave ratio system to be used to compute exact center frequencies
% base: 'base-ten' or 'base-two'
%
% exact center frequencies are returned by default using base-ten system's octave ratio
 


% OctOrThird = '1/3';
% fmin = 20;
% fmax = 22049;
if ~exist('base','var')
    base = 'base-ten';
end

nominalCFreqs12=[16 22.4 31.5 45 63 90 125 180 250 355 500 710 1000 1400 2000 2800 4000 5600 8000 11200 16000];
nominalCFreqs13=[1 1.25 1.6 2 2.5 3.15 4 5 6.3 8 10];

n_divide=-1;
tNCF=nominalCFreqs13;
switch OctOrThird
    case '1/1',  tNCF=nominalCFreqs12(1:2:end);
    case '1/2',  tNCF=nominalCFreqs12;
    case '1/3',  n_divide=0;
    case '1/6',  n_divide=1;
    case '1/12', n_divide=2;
    case '1/24', n_divide=3;
    otherwise disp(['ERROR: unknown bandwidth: ''' OctOrThird '''']);   return;
end
% 1/3-nál finomabb esetben több lépésben mindig tovább felezünk
for n=1:n_divide
    tempCF= sqrt(tNCF(1:end-1).*tNCF(2:end));
    tNCF(1:2:end*2-1)=tNCF;
    tNCF(2:2:end-1)=tempCF;
end
tNCF=tNCF(1:end-1);

min_kitevo=floor(log10(fmin)/3-1)*3; % mivel az oktávsáv 3 dekádonként ismőtlidik
max_kitevo=ceil(log10(fmax));        % ha pont kerek dekád a max. frek. akkor is egy dekáddal fölé megyünk

nominalCFreqs=[];
for n=min_kitevo:max_kitevo
    if n_divide>=0 | mod(n,3)==0
        nominalCFreqs=[nominalCFreqs  tNCF*10^n];
    end
end

% nominalCFreqs(find(nominalCFreqs<fmin)) = []; 
% nominalCFreqs(find(nominalCFreqs>fmax)) = []; 
% sprintf('%g\n',nominalCFreqs)

%% Exact center frequencies
f_ref = 1000;
switch lower(base)
    case 'base-ten', G = 10^(3/10); % base-ten exact - this is the ANSI preferred
    case 'base-two', G = 2; % base-two exact
    otherwise error('Invalid base for exact frequency computation. Possible values: ''base-ten'' or ''base-two''')
end

b= str2num(OctOrThird(3:end));
% x = [floor(b*log(fmin/f_ref)/log(G)) : ceil(b*log(fmax/f_ref)/log(G))];
x = [round(b*log(nominalCFreqs(1)/f_ref)/log(G)) : round(b*log(nominalCFreqs(end)/f_ref)/log(G))];

exactCFreqs = G.^(x/b)*f_ref;

fLow=exactCFreqs/G^(1/(2*b));
fHigh=exactCFreqs*G^(1/(2*b));

% invalid_pos=[find(fLow<fmin), find(fHigh>fmax)];
invalid_pos=[find(nominalCFreqs<fmin), find(nominalCFreqs>fmax)];

nominalCFreqs(invalid_pos) = [];
exactCFreqs(invalid_pos) = [];
fLow(invalid_pos) = [];
fHigh(invalid_pos) = [];

% sprintf('%g\n',exactCFreqs)